==> bitcream-ndt-custom-v0.7.2-768328.zip: common/models/Category.php <==
<?php

namespace bitcream\ndt\custom\common\models;

use Yii;
use yii\helpers\ArrayHelper;
use bitcream\pim\custom\common\models\Product;
use bitcream\pim\custom\common\models\Attribute;
use bitcream\pim\custom\common\models\ProductValue;
use yii\helpers\Inflector;
use bitcream\ndt\sync\wp\common\behaviors\SyncWpMediaBehavior;
use bitcream\ndt\sync\wp\common\behaviors\SyncWpTaxonomyBehavior;
/**
 * This is the extended model class for table "{{%product}}".
 */
class Category extends \bitcream\pim\custom\common\models\Product
{    
    public static $modelSlug = "category";

    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'taxonomySyncStatus' => [
                'class' => SyncWpTaxonomyBehavior::class,
                'attributes' => [
                    'decors-category',
                ],
                'syncProperties' => [
                    'taxonomy' => 'getTaxonomyFromProduct', 
                ]
            ],
            'mediaSyncStatus' => [
                'class' => SyncWpMediaBehavior::class,
                'attributes' => [
                    'cover_image',
                ],
                'syncProperties' => [
                    'media_file' => 'getDynamicProductMediaFile',
                ]
            ]
       ]);
    }

    public function fields(){
        return [
            'id',
            'title',
            'slug' => 'slug',
            'description', 
        ];
    }

    public function getTaxonomyFromProduct(string $attribute){
        $response = [
            'name' => 'Categorie decori',
            'slug' => $attribute,
            'terms' => [
                [
                    'title' => $this->title,
                    'meta' => [
                        '_thumbnail_id' => (!empty($this->getMediaObject('cover_image')))? $this->getMediaObject('cover_image')->remote_object: "",
                    ],
                ],                    
            ],
        ];
        return $response;
    }

    /**
     * Gets query for [[Decoration]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getDecorations()
    {
        return $this->hasMany(Decoration::className(), ['product_parent_id' => 'id'])->andWhere(['status' => '30']);
    }


    public function getSlug(){
        return Inflector::slug($this->title, '-');
    }

    public function getPhoto(){        
        return $this->getDynamicAttributeValue("photo");        
    }

    public function setPhoto($value){        
        return $this->setDynamicAttribute("photo", $value);        
    }

    public function getCover_image(){        
        return $this->getDynamicAttributeValue("cover_image");        
    }

    public function setCover_image($value){        
        return $this->setDynamicAttribute("cover_image", $value);        
    }

    public function getDrawing(){        
        return $this->getDynamicAttributeValue("drawing");        
    }

    public function setDrawing($value){        
        return $this->setDynamicAttribute("drawing", $value);        
    }

    public function getData_sheet(){        
        return $this->getDynamicAttributeValue("data_sheet");        
    }

    public function setData_sheet($value){        
        return $this->setDynamicAttribute("data_sheet", $value);        
    }

}

==> bitcream-ndt-custom-v0.8.2-5127a3.zip: common/models/Category.php <==
<?php

namespace bitcream\ndt\custom\common\models;

use Yii;
use yii\helpers\ArrayHelper;
use bitcream\pim\custom\common\models\Product;
use bitcream\pim\custom\common\models\Attribute;
use bitcream\pim\custom\common\models\ProductValue;
use bitcream\ndt\custom\common\models\CustomerUser;
use bitcream\ndt\custom\common\models\ProductTranslation;
use yii\helpers\Inflector;
use bitcream\ndt\sync\wp\common\behaviors\SyncWpMediaBehavior;
use bitcream\ndt\sync\wp\common\behaviors\SyncWpTaxonomyBehavior;
/**
 * This is the extended model class for table "{{%product}}".
 */
class Category extends \bitcream\pim\custom\common\models\Product
{    
    public static $modelSlug = "category";

    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'taxonomySyncStatus' => [
                'class' => SyncWpTaxonomyBehavior::class,
                'attributes' => [
                    'decors-category',
                ],
                'syncProperties' => [
                    'taxonomy' => 'getTaxonomyFromProduct', 
                ]
            ],
            'mediaSyncStatus' => [
                'class' => SyncWpMediaBehavior::class,
                'attributes' => [
                    'cover_image',
                ],
                'syncProperties' => [
                    'media_file' => 'getDynamicProductMediaFile',
                ]
            ]
       ]);
    }

    public function fields(){
        return [
            'id',
            'title',
            'slug' => 'slug',
            'description', 
        ];
    }

    public function getTaxonomyFromProduct(string $attribute){
        $response = [
            'name' => 'Categorie decori',
            'slug' => $attribute,
            'terms' => [
                [
                    'title' => $this->title,
                    'meta' => [
                        '_thumbnail_id' => (!empty($this->getMediaObject('cover_image')))? $this->getMediaObject('cover_image')->remote_object: "",
                    ],
                ],                    
            ],
        ];
        return $response;
    }

    /**
     * Gets query for [[Decoration]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getDecorations()
    {
        return $this->hasMany(Decoration::className(), ['product_parent_id' => 'id'])->andWhere(['status' => '30']);
    }


    public function getSlug(){
        return Inflector::slug($this->title, '-');
    }

    public function getPhoto(){        
        return $this->getDynamicAttributeValue("photo");        
    }

    public function setPhoto($value){        
        return $this->setDynamicAttribute("photo", $value);        
    }

    public function getCover_image(){        
        return $this->getDynamicAttributeValue("cover_image");        
    }

    public function setCover_image($value){        
        return $this->setDynamicAttribute("cover_image", $value);        
    }

    public function getDrawing(){        
        return $this->getDynamicAttributeValue("drawing");        
    }

    public function setDrawing($value){        
        return $this->setDynamicAttribute("drawing", $value);        
    }

    public function getData_sheet(){        
        return $this->getDynamicAttributeValue("data_sheet");        
    }

    public function setData_sheet($value){        
        return $this->setDynamicAttribute("data_sheet", $value);        
    }

    public function getTitle(){
        $products = ProductTranslation::find()->where(['product_id' => $this->id, 'status' => '30'])->all();
        if(!empty($products)){
            $customerUser = CustomerUser::findOne(Yii::$app->user->id);
        }  
        if(!empty($customerUser)){
            $language = $customerUser->language;
        }
        if(!empty($language)){
            $productTranslation = ProductTranslation::getTranslation($language, $products); 
            if(!empty($productTranslation))
                return $productTranslation->title;
        }  
        return $this->title;
    }

    public function getDescription(){
        $products = ProductTranslation::find()->where(['product_id' => $this->id, 'status' => '30'])->all();
        if(!empty($products)){
            $customerUser = CustomerUser::findOne(Yii::$app->user->id);
        }  
        if(!empty($customerUser)){
            $language = $customerUser->language;
        }
        if(!empty($language)){
            $productTranslation = ProductTranslation::getTranslation($language, $products); 
            if(!empty($productTranslation))
                return $productTranslation->description;
        }  

        return $this->description;
    }

    /**
     * Gets query for [[Products]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getProductsTranslation()
    {
        return $this->hasMany(ProductTranslation::className(), ['product_id' => 'id']);
    }


}
